# Copyright (c) 2018 exstnce
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# File: install.rb
# Project: dotfiles-cli
# Author: exstnce (exstnce@protonmail.ch)
# Created on Sunday, 8th July 2018 9:55:50 pm

require 'dotfiles/utils/fs'
require 'dotfiles/utils/permissive'

module Install
  include Sudo
  include FileSystem
  # /etc
  @@etc = '/etc/'
  # ~/
  @@root = File.expand_path('~')+'/'
  # ~/Scripts
  @@scripts = @@root+'Scripts/'
  # ~/Pictures
  @@pictures = @@root+'Pictures/'
  # ~/.config
  @@config = @@root+'.config/'

  def self.etc(path)
    contents = FileSystem.contents(path)
    Sudo.copy(contents, @@etc)
  end

  def self.config(path)
    contents = FileSystem.contents(path)
    Sudo.copy(contents, @@config)
  end

  def self.tools(path)
    contents = FileSystem.contents(path)
    Sudo.copy(contents, @@root)
  end

  def self.scripts(name, path)
    contents = FileSystem.contents(path)
    scripts = FileSystem.mkdir(@@scripts+name)

    Sudo.copy(contents, scripts)
  end

  def self.wallpapers(name, path)
    contents = FileSystem.contents(path)
    pictures = FileSystem.mkdir(@@pictures+name)

    Sudo.copy(contents, pictures)
  end
end