# Copyright (c) 2018 exstnce
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# File: options.rb
# Project: dotfiles-cli
# Author: exstnce (exstnce@protonmail.ch)
# Created on Friday, 6th July 2018 5:26:25 pm

require 'optparse'

require 'dotfiles/core'
require_relative 'parser'

module Options
  include Core
  include CommandParser
  @version = 'dotfiles 0.1.0'

  def self.parse
    OptionParser.new do |opts|

      opts.on('-h', '--help', 'Show help message') do
        Core.help
      end

      opts.on('-v', '--version', 'Show dotfiles version') do
        puts @version
        exit
      end
    end.parse!

    CommandParser.new do |opts|
      opts.on_empty do
        Core.help
      end

      opts.on('help') do |command|
        Core.help(command)
      end

      opts.on('install') do |link|
        if link.nil?
          Core.help('install')
        end

        Core.install(link)
      end

      opts.on('use') do |name|
        if name.nil?
          Core.help('use')
        end

        Core.use(name)
      end

      opts.on('save') do
        Core.save
        abort("No results were returned for that query")
      end

      opts.on('delete') do |name|
        if name.nil?
          Core.help('delete')
        end
        
        Core.delete(name)
      end
    end
  end
end